# Pybsky

<div align='center'>

![./a](./assets/cover.png)

</div>

# Requirements
Python 3.10+

Pybsky stands on the shoulder of:
- requests package

# Installation
<div class="termy">
  
```console
 $ pip install pybsky

---> 100%
```
</div>

## Feature List:

- [x] Create Client
- [x] Add Login logic
- [x] Get Profile logic
- [x] Get Follwer/Following logic
- [x] Follow/Unfollow
- [x] Get likes
- [x] Get post, thread via replies
- [x] Get Author Feed/Timeline
- [x] Create post (text and image)

## License

[![License](http://img.shields.io/:license-mit-blue.svg?style=flat-square)](http://badges.mit-license.org)

- This project is licensed under the terms of the **[MIT license](LICENSE)**
